@@ -104,6 +104,10 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
                                 cpl_frame *schlf_n, cpl_frame *schlf_s,
                                 const char *expkey, const char *amkey,
                                 float magerrcut, int *status);
+
+extern int casu_remove_mag_inside_range(casu_tfits **mstds, const int nimages,
+										char *filt, cpl_table *phottab,
+										const float low_mag, const float high_mag);
 extern float
 casu_calculate_abmag_lim(const float zeropoint, const float skynoise,
 		const float r_core, const float eff_expt, const float apcor3, const float extinction);
