@@ -31,6 +31,7 @@
 #include <config.h>
 #endif
 
+#define _XOPEN_SOURCE
 #include <cpl.h>
 #include <math.h>
 #include <string.h>
@@ -202,9 +203,9 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
                                 float magerrcut, int *status) {
     float **stdmagptr,*resall3,*resall5,apcor3,apcor5,exptime,**magerrptr;
     float airmass,*catcore3,*catcore5,*resim3,*resim5,cf,fluxmag3,fluxmag5;
-    float refmag,extinct,dm3,dm5,med3,mad,med5,sig3,sig5,blankvalue2=0.0;
+    float refmag,extinct,dm3,dm5,med3,mad,med5,sig3,sig5;
     float rcore,lim5,dx,skylev,skbrt,*ebmvall,*zps3,*zps5,medebv,med;
-    float sig3det,sig5det,*ebmv,blankvalue=-99.0,satlev,sumskbr;
+    float sig3det,sig5det,*ebmv,blankvalue=-99.0,sumskbr;
     float sknoise,sumsat;
     int nresall,nalloc_resall,i,j,k,ncat,nresim,nresimtot;
     int ngood,oops,nlim,isrubbish,*dodgy,crud;
@@ -320,7 +321,6 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
         rcore = cpl_propertylist_get_float(ehu_cat,"ESO DRS RCORE");
         skylev = cpl_propertylist_get_float(ehu_cat,"ESO DRS SKYLEVEL");
         sknoise = cpl_propertylist_get_float(ehu_cat,"ESO DRS SKYNOISE");
-        satlev = cpl_propertylist_get_float(ehu_cat,"ESO QC SATURATION");
         dx = pixsize(ehu_im);
         exptime = (float)cpl_propertylist_get_double(phu_im,expkey);
         airmass = (float)cpl_propertylist_get_double(phu_im,amkey);
@@ -343,7 +343,6 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
         ebmv = cpl_table_get_data_float(stds,"ebmv");
         for (j = 0; j < p.ncolumns_coleq; j++) {
             cpl_table_fill_invalid_float(stds,(p.coleq_columns)[j],blankvalue);
-            cpl_table_fill_invalid_float(stds,(p.coleq_columns)[j],blankvalue2);
             stdmagptr[j] = cpl_table_get_data_float(stds,(p.coleq_columns)[j]);
             if (magerrptr != NULL) {
 		cpl_table_fill_invalid_float(stds,(p.coleq_errcols)[j],blankvalue);
@@ -736,6 +735,65 @@ extern int casu_photcal_extinct(casu_fits **images, casu_tfits **mstds,
 
 }
 
+/*---------------------------------------------------------------------------*/
+/**
+	\par Name:
+		casu_remove_mag_inside_range
+	\par Purpose:
+		Remove from mstds the stars having magnitude between low_mag and high_mag
+	\par Description:
+		Remove from mstds the stars having magnitude between low_mag and high_mag
+	\par Language:
+		C
+	\param mstds
+		The matched standards tables list
+	\param nimages
+		Number of elements in the matched standards tables list
+	\param filt
+		The name of the filter for the observation
+	\param phottab
+		The relevant table for photometric calibration for a given standard
+		source
+	\param low_mag
+		The lower bound of the range to remove
+	\param high_mag
+		The upper bound of the range to remove
+	\return The number of removed stars, -1 in case of error
+	\author
+		Matteo Salmistraro, ESO
+*/
+/*---------------------------------------------------------------------------*/
+extern int casu_remove_mag_inside_range(casu_tfits **mstds, const int nimages,
+										 char *filt, cpl_table *phottab,
+										 const float low_mag, const float high_mag)
+{
+
+	photstrct p;
+
+	if (casu_phot_open(phottab,filt,&p) != CASU_OK)
+		return -1;
+
+	int i, j;
+	int num_erased = 0;
+	for (i = 0; i < nimages; i++) {
+		 casu_tfits * ctfits = mstds[i];
+		 cpl_table * stds = casu_tfits_get_table(ctfits);
+		 cpl_table_unselect_all(stds);
+		 for (j = 0; j < p.ncolumns_coleq; j++) {
+			 const char * clnm_name = (p.coleq_columns)[j];
+			 cpl_table_and_selected_float(stds, clnm_name, CPL_GREATER_THAN, low_mag);
+			 cpl_table_and_selected_float(stds, clnm_name, CPL_LESS_THAN, high_mag);
+		 }
+		 num_erased += cpl_table_count_selected(stds);
+		 cpl_table_erase_selected(stds);
+		 cpl_table_select_all(stds);
+	}
+
+	casu_phot_close(&p);
+	return num_erased;
+}
+
+
 /*---------------------------------------------------------------------------*/
 /**
     \par Name:
@@ -953,11 +1011,12 @@ static int extract_columns(cpl_table *tab, photstrct *p) {
         /* Now parse the string into the column names */
 
         z = cpl_malloc(nv*sizeof(char *));
+        char *saveptr = NULL;
         for (i = 0; i < nv; i++) {
             if (i == 0) 
-                w = strtok(v,",");
+                w = strtok_r(v,",",&saveptr);
             else
-                w = strtok(NULL,",");
+                w = strtok_r(NULL,",",&saveptr);
             z[i] = cpl_strdup(w);
         }
         if (k == 0) 
@@ -1011,11 +1070,12 @@ static int extract_coleq(cpl_table *tab, photstrct *p) {
     /* Now parse the string into the colour equation values */
 
     z = cpl_malloc(nv*sizeof(float));
+    char *saveptr1;
     for (i = 0; i < nv; i++) {
         if (i == 0) 
-            w = strtok(v,",");
+            w = strtok_r(v,",", &saveptr1);
         else
-            w = strtok(NULL,",");
+            w = strtok_r(NULL,",", &saveptr1);
         z[i] = (float)atof(w);
     }
     p->coleq_coefs = z;
