@@ -31,6 +31,7 @@
 #include <config.h>
 #endif
 
+#define _XOPEN_SOURCE
 #include <sys/time.h>
 #include <time.h>
 #include <libgen.h>
@@ -914,11 +915,12 @@ extern void casu_timestamp(char *out, int n) {
     struct timeval tv;
     struct tm *tm;
     float sec;
-    
+    struct tm result;
     /* Get the Greenwich Mean Time */
 
     (void)gettimeofday(&tv,NULL);
-    tm = gmtime(&(tv.tv_sec));
+
+    tm = gmtime_r(&(tv.tv_sec), &result);
     sec = (float)tm->tm_sec + 1.0e-6*(float)tv.tv_usec;
 
     /* Now format it */
