@@ -31,7 +31,7 @@ $Id: classify.h,v 1.3 2015/09/22 15:09:20 jim Exp $
 
 /* Prototype */
 
-extern int imcore_classify(casu_tfits *, cpl_propertylist *, float, int);
+extern int imcore_classify(casu_tfits *, float, int);
 
 #endif
 
