@@ -48,6 +48,11 @@
  */
 /*----------------------------------------------------------------------------*/
 
+cpl_error_code hawki_image_copy_to_intersection
+(cpl_image        * target,
+ const cpl_image  * from,
+ cpl_size           target_shift_x,
+ cpl_size           target_shift_y);
 /**@{*/
 
 /** 
@@ -118,8 +123,9 @@ cpl_error_code hawki_image_copy_to_intersection
             const void * from_p; 
             void       * target_p;
             
-            from_p   = from_data   + (inter_x1 + iy * from_nx) * pixel_size;
-            target_p = target_data +
+            from_p   = (const uint8_t*)from_data   + 
+                    (inter_x1 + iy * from_nx) * pixel_size;
+            target_p = (uint8_t*)target_data +
                     (inter_x1 - target_shift_x +
                             (iy - target_shift_y) * target_nx) * pixel_size;
             memcpy(target_p, from_p, memcopy_size);
