@@ -521,116 +521,10 @@ int hawki_compute_harmonization(
     return 0 ;
 }
 
-/*----------------------------------------------------------------------------*/
-/** 
-   @brief   Compute the large scale background
-   @param   the input image
-   @return  The background or NULL in error case
- */
-/*----------------------------------------------------------------------------*/
-cpl_image * hawki_compute_lsbg(const cpl_image * in)
-{
-    cpl_image       *   out ;
-    cpl_image       *   tmp ;
-    cpl_image       *   filtered ;
-    cpl_image       *   subsampled ;
-    cpl_mask        *   kernel ;
-    int                 nscales ;
-    cpl_polynomial  *   poly ;
-    cpl_bivector    *   xy_pos ;
-    cpl_vector      *   vals ;
-    int                 quad_sz, nbpoints, lx, ly, nx, ny ;
-    double          *   pxy_pos_x ;
-    double          *   pxy_pos_y ;
-    double          *   pvals ;
-    float           *   pima ;
-    int                 i, j ;
-
-    /* Check entries */
-    if (in == NULL) return NULL ;
-    nx = cpl_image_get_size_x(in) ;
-    ny = cpl_image_get_size_y(in) ;
-    
-    /* Initialise */
-    nscales = 7 ;
-    tmp = (cpl_image *)in ;
-    subsampled = NULL ;
-    
-    /* Check entries */
-    quad_sz = pow(2, (double)nscales) ;
-    lx = nx / quad_sz ;
-    ly = ny / quad_sz ;
-    nbpoints = lx * ly ;
-    if (quad_sz >= nx || quad_sz >= ny) return NULL ;
-
-    /* Create filter kernel */
-    kernel = cpl_mask_new(3, 3) ;
-    cpl_mask_not(kernel) ;
-
-    /* Loop nscales times */
-    for (i=0 ; i<nscales ; i++) {
-
-        /* Filter the image */
-        filtered = cpl_image_new(cpl_image_get_size_x(tmp),
-                                 cpl_image_get_size_y(tmp),
-                                 cpl_image_get_type(tmp));
-        cpl_image_filter_mask(filtered, in, kernel, CPL_FILTER_MEDIAN, 
-                              CPL_BORDER_FILTER);
-        if (i>0) cpl_image_delete(tmp) ;
-
-        /* Subsample the image */
-        subsampled = cpl_image_extract_subsample(filtered, 2, 2) ;
-        cpl_image_delete(filtered) ;
-    
-        tmp = subsampled ;
-    }
-    cpl_mask_delete(kernel) ;
-
-    /* Check nbpoints */
-    if (nbpoints != 
-            cpl_image_get_size_x(subsampled)*cpl_image_get_size_y(subsampled)) {
-        cpl_msg_error(__func__, "Invalid size") ;
-        cpl_image_delete(subsampled) ;
-        return NULL ;
-    }
-    
-    /* Create anchor points for the fit */
-    xy_pos = cpl_bivector_new(nbpoints) ;
-    vals = cpl_vector_new(nbpoints) ;
-    pxy_pos_x = cpl_bivector_get_x_data(xy_pos) ;
-    pxy_pos_y = cpl_bivector_get_y_data(xy_pos) ;
-    pvals = cpl_vector_get_data(vals) ;
-    pima = cpl_image_get_data_float(subsampled) ;
-    for (j=0 ; j<ly ; j++) {
-        for (i=0 ; i<lx ; i++) {
-            pxy_pos_x[i+j*lx] = i * quad_sz + quad_sz/2 ;
-            pxy_pos_y[i+j*lx] = j * quad_sz + quad_sz/2 ;
-            pvals[i+j*lx] = (double)pima[i+j*lx];
-        }
-    }
-    cpl_image_delete(subsampled) ;
-
-    /* Fit the polynomial */
-    if ((poly = cpl_polynomial_fit_2d_create(xy_pos, vals, 3, NULL)) == NULL) {
-        cpl_msg_error(__func__, "Cannot fit the polynomial") ;
-        cpl_bivector_delete(xy_pos) ;
-        cpl_vector_delete(vals) ;
-        return NULL ;
-    }
-    cpl_bivector_delete(xy_pos) ;
-    cpl_vector_delete(vals) ;
-
-    /* Regenerate the big bgd image */
-    out = cpl_image_duplicate(in) ;
-    cpl_image_fill_polynomial(out, poly, 1.0, 1.0, 1.0, 1.0) ;
-    cpl_polynomial_delete(poly) ;
-    
-    return out ;
-}
 
 /*----------------------------------------------------------------------------*/
 /** 
-   @brief   Extract the filename ﬀor the first frame of the given tag
+   @brief   Extract the filename for the first frame of the given tag
    @param   in      A non-empty frameset
    @param   tag     The tag of the requested file 
    @return  Pointer to the file
@@ -878,10 +772,13 @@ int hawki_detectors_locate_star
                 cpl_propertylist_delete(main_header);
                 return -1;
             }
+            /*Fixing a compiler warning as before cleanstate was CPL_ERROR_NONE
+             * Probably all of this errorstate setting is not needed*/
+            cpl_errorstate cleanstate = cpl_errorstate_get();
             if(irplib_wcs_radectoxy(wcs, star_ra, star_dec, &star_x, &star_y)
                     != CPL_ERROR_NONE)
             {
-                cpl_errorstate_set(CPL_ERROR_NONE);
+                cpl_errorstate_set(cleanstate);
             }
             
             /* Check for the limits */
