@@ -104,7 +104,7 @@ typedef enum {
 } irplib_strehl_bg_method;
 
 /*-----------------------------------------------------------------------------
-                               Functions prototypes
+                               Function prototypes
  -----------------------------------------------------------------------------*/
 
 cpl_error_code irplib_strehl_compute(const cpl_image *, double, double, double,
@@ -112,12 +112,7 @@ cpl_error_code irplib_strehl_compute(const cpl_image *, double, double, double,
                                      double, double, double, int, int,
                                      double *, double *, double *, double *,
                                      double *, double *, double *, double *);
-cpl_error_code irplib_strehl_mark_bad_and_compute(
-					cpl_image *, double, double, double,
-					double, double, int, double, double,
-					double, double, double, int, int,
-					double *, double *, double *, double *,
-					double *, double *, double *, double *);
+
 double irplib_strehl_disk_flux(const cpl_image *, double, double, double,
                                double);
 
