@@ -1,7 +1,6 @@
-/* $Id: irplib_wlxcorr.c,v 1.58 2013-01-29 08:43:33 jtaylor Exp $
- *
+/*
  * This file is part of the IRPLIB package
- * Copyright (C) 2002,2003 European Southern Observatory
+ * Copyright (C) 2002,2003,2014 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013-01-29 08:43:33 $
- * $Revision: 1.58 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -33,15 +25,15 @@
    								Includes
  -----------------------------------------------------------------------------*/
 
-#include <math.h>
-#include <string.h>
-
-#include <cpl.h>
-
 #include "irplib_wavecal_impl.h"
 
 #include "irplib_wlxcorr.h"
 
+#include <cpl.h>
+
+#include <math.h>
+#include <string.h>
+
 /*----------------------------------------------------------------------------*/
 /**
  * @defgroup irplib_wlxcorr     Wavelength Cross correlation w. plotting
@@ -58,13 +50,6 @@
                            Defines
  -----------------------------------------------------------------------------*/
 
-/* TEMPORARY SUPPORT OF CPL 5.x */
-#ifndef CPL_SIZE_FORMAT
-#define CPL_SIZE_FORMAT "d"
-#define cpl_size int
-#endif
-/* END TEMPORARY SUPPORT OF CPL 5.x */
-
 #ifndef inline
 #define inline /* inline */
 #endif
@@ -367,10 +352,10 @@ cpl_table * irplib_wlxcorr_gen_spc_table(
                                 corr_poly, spec_sz, 1.0);
     cpl_error_code      error;
 
-    cpl_msg_debug(cpl_func, "Tabel for guess dispersion polynomial (slitw=%g, "
+    cpl_msg_debug(cpl_func, "Table for guess dispersion polynomial (slitw=%g, "
                   "fwhm=%g) with %d-point observed spectrum with%s catalog re"
                   "sampling", slitw, fwhm, spec_sz, guess_resamp ? "out" : "");
-    cpl_msg_debug(cpl_func, "Tabel for corr. dispersion polynomial (slitw=%g, "
+    cpl_msg_debug(cpl_func, "Table for corr. dispersion polynomial (slitw=%g, "
                   "fwhm=%g) with %d-point observed spectrum with%s catalog re"
                   "sampling", slitw, fwhm, spec_sz, corr_resamp ? "out" : "");
 
@@ -513,7 +498,7 @@ cpl_bivector * irplib_wlxcorr_cat_extract(
         return NULL ;
     }
     /* The last line must be less than wave_max */
-    if (dxlines[wave_max_id] >= wave_min) wave_max_id--;
+    if (dxlines[wave_max_id] >= wave_max) wave_max_id--;
 
     /* Checking the wavelength range at this point via the indices also
        verifies that they were not found using non-increasing wavelengths */
@@ -530,7 +515,7 @@ cpl_bivector * irplib_wlxcorr_cat_extract(
     sub_cat_wl = cpl_vector_extract(xlines, wave_min_id, wave_max_id, 1);
     sub_cat_int = cpl_vector_extract(cpl_bivector_get_y_const(lines_catalog), 
                                      wave_min_id, wave_max_id, 1);
- 
+
     return cpl_bivector_wrap_vectors(sub_cat_wl, sub_cat_int);
 }
 
@@ -654,8 +639,6 @@ int irplib_wlxcorr_plot_solution(
 {
     int                 nsamples, nplots ;
     cpl_vector      **  vectors ;
-    cpl_bivector    *   bivector ;
-    double              diff ;
     int                 i ;
     
     /* Test entries */
@@ -700,6 +683,7 @@ int irplib_wlxcorr_plot_solution(
     /* Second plot with the delta-lambda/pixel relation */
     /* Fill vectors */
     for (i=0 ; i<nsamples ; i++) {
+        double              diff ;
         cpl_vector_set(vectors[0], i, pix_start+i) ;
         diff = cpl_polynomial_eval_1d(comp, (double)(pix_start+i), NULL) -
             cpl_polynomial_eval_1d(init, (double)(pix_start+i), NULL) ;
@@ -713,6 +697,7 @@ int irplib_wlxcorr_plot_solution(
 
     /* Plot */
     if (sol == NULL) {
+        cpl_bivector    *   bivector ;
         bivector = cpl_bivector_wrap_vectors(vectors[0], vectors[1]) ;
         cpl_plot_bivector(
 "set grid;set xlabel 'Position (pixels)';set ylabel 'Wavelength difference';", 
@@ -755,7 +740,7 @@ int irplib_wlxcorr_plot_spc_table(
     cpl_vector      **  sub_vectors ;
     cpl_vector      *   tmp_vec ;
     int                 nsamples ;
-    double              max, mean1, mean3 ;
+    double              mean1, mean3 ;
     int                 start_ind, stop_ind, hsize_pix ;
     int                 i, j ;
 
@@ -806,6 +791,7 @@ int irplib_wlxcorr_plot_spc_table(
     title_loc[1023] = (char)0 ;
     tmp_vec = cpl_vector_duplicate(vectors[2]) ;
     for (i=0 ; i<last_plotted_line ; i++) {
+        double max;
         /* Find the brightest line */
         if ((max = cpl_vector_get_max(tmp_vec)) <= 0.0) break ;
         for (j=0 ; j<nsamples ; j++) {
@@ -881,17 +867,17 @@ int irplib_wlxcorr_catalog_plot(
     if (pwave[nvals_tot-1] <= wmax) stop = nvals_tot-1 ;
     else stop = -1 ;
     i=0 ;
-    while ((pwave[i] < wmin) && (i<nvals_tot-1)) i++ ;
+    while ((i<nvals_tot-1) && (pwave[i] < wmin)) i++ ;
     start = i ;
     i= nvals_tot-1 ;
-    while ((pwave[i] > wmax) && (i>0)) i-- ;
+    while ((i>0)           && (pwave[i] > wmax)) i-- ;
     stop = i ;
 
     if (start>=stop) {
         cpl_msg_error(cpl_func, "Cannot plot the catalog") ;
         return -1 ;
     }
-    nvals = start - stop + 1 ;
+    nvals = stop - start + 1 ;
 
     /* Create the bivector to plot */
     subcat_x = cpl_vector_extract(cpl_bivector_get_x_const(cat),start,stop, 1) ;
