@@ -26,14 +26,15 @@
  -----------------------------------------------------------------------------*/
 
 #include <math.h>
+#include <locale.h>
 #include <cpl.h>
 
 #include "irplib_utils.h"
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_image_stats.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
 #include "hawki_variance.h"
@@ -42,11 +43,6 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_cal_dark_create(cpl_plugin *) ;
 static int hawki_cal_dark_exec(cpl_plugin *) ;
 static int hawki_cal_dark_destroy(cpl_plugin *) ;
@@ -102,7 +98,7 @@ static struct {
 } hawki_cal_dark_outputs;
 
 static char hawki_cal_dark_description[] =
-"hawki_cal_dark -- Dark recipe\n"
+"(OBSOLETE) hawki_cal_dark -- Dark recipe\n"
 "The files listed in the Set Of Frames (sof-file) must be tagged:\n"
 "raw-file.fits "HAWKI_CAL_DARK_RAW" or\n"
 "raw-file.fits "HAWKI_TEC_FLAT_RAW".\n"
@@ -140,11 +136,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_cal_dark",
-                    "Dark recipe",
+                    "(OBSOLETE) Dark recipe",
                     hawki_cal_dark_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_cal_dark_create,
                     hawki_cal_dark_exec,
                     hawki_cal_dark_destroy) ;
@@ -322,7 +318,7 @@ static int hawki_cal_dark(
     }
  
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(frameset)) {
+    if (hawki_dfs_set_groups_legacy(frameset)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -353,8 +349,8 @@ static int hawki_cal_dark(
         cpl_frameset_delete(rawframes) ;
         return -1 ;
     }
-    hawki_cal_dark_outputs.dit = hawki_pfits_get_dit(plist) ;
-    hawki_cal_dark_outputs.ndit = hawki_pfits_get_ndit(plist) ;
+    hawki_cal_dark_outputs.dit = hawki_pfits_get_dit_legacy(plist) ;
+    hawki_cal_dark_outputs.ndit = hawki_pfits_get_ndit_legacy(plist) ;
     hawki_cal_dark_outputs.ndsamples = hawki_pfits_get_ndsamples(plist);
     cpl_propertylist_delete(plist) ;
     if(!cpl_errorstate_is_equal(error_prevstate))
@@ -369,8 +365,8 @@ static int hawki_cal_dark(
     cpl_msg_info(__func__, "NDSAMPLES value: %d", hawki_cal_dark_outputs.ndsamples);
     
     /* Check that DIT/NDIT and NDSAMPLES are the same for all the frames */
-    if(!hawki_utils_check_equal_double_keys(rawframes, &hawki_pfits_get_dit) ||
-       !hawki_utils_check_equal_int_keys(rawframes, &hawki_pfits_get_ndit)||
+    if(!hawki_utils_check_equal_double_keys(rawframes, &hawki_pfits_get_dit_legacy) ||
+       !hawki_utils_check_equal_int_keys(rawframes, &hawki_pfits_get_ndit_legacy)||
        !hawki_utils_check_equal_int_keys(rawframes, &hawki_pfits_get_ndsamples))
     {
         cpl_msg_error(__func__, "Not all input darks have the same "
@@ -817,7 +813,7 @@ static int hawki_cal_dark_save
     cpl_free(qclists) ;
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return -1;
     }
     return  0;
@@ -839,6 +835,7 @@ static int hawki_cal_dark_retrieve_input_param
     hawki_cal_dark_config.nsamples = cpl_parameter_get_int(par) ;
     par = cpl_parameterlist_find(parlist, "hawki.hawki_cal_dark.zone") ;
     sval = cpl_parameter_get_string(par) ;
+    setlocale(LC_NUMERIC, "C"); // Behaviour of sscanf depends on the locale
     if (sscanf(sval, "%d,%d,%d,%d",
                     &hawki_cal_dark_config.llx,
                     &hawki_cal_dark_config.lly,
