@@ -455,7 +455,6 @@ static int hawki_dark_combine(cpl_parameterlist *parlist,
     long i,npts;
     float exptime,*data,fval,med,rnorm;
     double dval;
-    char *key;
     casu_fits *ff;
     cpl_parameter *p;
     cpl_propertylist *plist;
@@ -636,7 +635,7 @@ static int hawki_dark_combine(cpl_parameterlist *parlist,
         vqc_median = cpl_vector_new((cpl_size)ps.ngood);
         vqc_ron = cpl_vector_new((cpl_size)ps.ngood);
         npts = nx*ny;
-        key = cpl_malloc(16);
+        //key = cpl_malloc(16);
         rnorm = 1.48*sqrt((double)ndit)/CPL_MATH_SQRT2;
         for (i = 0; i < ps.ngood; i++) {
             data = cpl_image_get_data_float(casu_fits_get_image(ps.good[i]));
@@ -654,12 +653,14 @@ static int hawki_dark_combine(cpl_parameterlist *parlist,
             casu_medmad(data,bpm,npts,&med,&fval);
             fval *= rnorm;
             cpl_vector_set(vqc_ron,(cpl_size)i,(double)fval);
-            (void)snprintf(key,16,"ESO QC RON%" CPL_SIZE_FORMAT,(cpl_size)(i+1));
+            char * key = cpl_sprintf("ESO QC RON%ld", (i+1));
+            //(void)snprintf(key,16,"ESO QC RON%" CPL_SIZE_FORMAT,(cpl_size)(i+1));
             cpl_propertylist_append_double(cs.qc,key,(double)fval);
             cpl_propertylist_set_comment(cs.qc,key,"Readnoise estimate from pair");
+            cpl_free(key);
             cpl_image_delete(diff);
         }
-        cpl_free(key);
+
         dval = cpl_vector_get_mean(vqc_mean);
         cpl_propertylist_append_double(cs.qc,"ESO QC RAW MEAN MEAN",dval);
         cpl_propertylist_set_comment(cs.qc,"ESO QC RAW MEAN MEAN",
