@@ -848,15 +848,25 @@ static cpl_error_code hawki_setqc_detector_noise(const cpl_table *tab,
             gain = cpl_table_get_float(tab, "GAIN", i, NULL);
             extname = cpl_table_get_string(tab, "EXTNAME", i);
 
-            qcname = cpl_sprintf("ESO QC RON %s", extname);
+            /* Replace the "." with a "-" to obay DICD rules */
+            char * extname_mod = cpl_strdup(extname);
+            for (size_t index = 0; index < strlen(extname_mod); index++)
+            {
+                if(extname_mod[index] == '.') {
+                    extname_mod[index] = '-';
+                }
+            }
+
+            qcname = cpl_sprintf("ESO QC RON %s", extname_mod);
             cpl_propertylist_update_float(qclist, qcname, readnoise);
             cpl_propertylist_set_comment(qclist,qcname,"Read-out noise in ADU");
             cpl_free(qcname);
 
-            qcname = cpl_sprintf("ESO QC GAIN %s", extname);
+            qcname = cpl_sprintf("ESO QC GAIN %s", extname_mod);
             cpl_propertylist_update_float(qclist, qcname, gain);
             cpl_propertylist_set_comment(qclist,qcname,"Gain in e-/ADU");
             cpl_free(qcname);
+            cpl_free(extname_mod);
 
         }
     }
