@@ -674,6 +674,8 @@ static int hawki_science_postprocess(cpl_parameterlist *parlist,
         cs.cdssearch_astrom = 3;
     else if (! strcmp(cpl_parameter_get_string(p),"wise")) 
         cs.cdssearch_astrom = 5;
+    else
+        cs.cdssearch_astrom = 0; /* Fallback is to use none */
     p = cpl_parameterlist_find(parlist,
                                "hawki.hawki_science_postprocess.cdssearch_photom");
     if (! strcmp(cpl_parameter_get_string(p),"none")) 
@@ -682,6 +684,8 @@ static int hawki_science_postprocess(cpl_parameterlist *parlist,
         cs.cdssearch_photom = 1;
     else if (! strcmp(cpl_parameter_get_string(p),"ppmxl")) 
         cs.cdssearch_photom = 3;
+    else
+        cs.cdssearch_photom = 0; /* Fallback is to use none */
     p = cpl_parameterlist_find(parlist,
                                "hawki.hawki_science_postprocess.stk_fast");
     if (! strcmp(cpl_parameter_get_string(p),"auto"))
@@ -690,6 +694,8 @@ static int hawki_science_postprocess(cpl_parameterlist *parlist,
         cs.stk_fast = 0;
     else if (! strcmp(cpl_parameter_get_string(p),"fast"))
         cs.stk_fast = 1;
+    else
+        cs.stk_fast = -1; /* Fallback is to auto */
     p = cpl_parameterlist_find(parlist,
                                "hawki.hawki_science_postprocess.stk_nfst");
     cs.stk_nfst = cpl_parameter_get_int(p);
@@ -866,7 +872,8 @@ static int hawki_science_postprocess(cpl_parameterlist *parlist,
         nfail += hawki_testfrm_1(ps.catindex_p,1,0,0);
         pp = cpl_propertylist_load(cpl_frame_get_filename(ps.catindex_p),1);
         if (cpl_propertylist_has(pp,"EXTNAME")) {
-            strncpy(pcat,cpl_propertylist_get_string(pp,"EXTNAME"),32);
+            strncpy(pcat,cpl_propertylist_get_string(pp,"EXTNAME"),32-1);
+            pcat[32-1] = '\0';
         } else {
             cpl_msg_error(fctid,"No extension name in %s",
                           cpl_frame_get_filename(ps.catindex_p));
@@ -875,11 +882,13 @@ static int hawki_science_postprocess(cpl_parameterlist *parlist,
         cpl_propertylist_delete(pp);
     } else if (ps.master_mstd_phot != NULL) {
         pp = cpl_propertylist_load(cpl_frame_get_filename(ps.master_mstd_phot),0);
-        strncpy(pcat,cpl_propertylist_get_string(pp,"PHOTCAT"),32);
+        strncpy(pcat,cpl_propertylist_get_string(pp,"PHOTCAT"),32-1);
+        pcat[32-1] = '\0';
         cpl_propertylist_delete(pp);
     } else {
         (void)casu_getstds_cdslist(cs.cdssearch_photom,&junk1,&junk2,&status);
-        strncpy(pcat,junk1,32);
+        strncpy(pcat,junk1,32-1);
+        pcat[32-1] = '\0';
         freespace(junk1);
         freespace(junk2);
         if (status != CASU_OK) {
