@@ -38,12 +38,12 @@
 #include <cpl.h>
 
 #include "irplib_utils.h"
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_calib.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 
 /*-----------------------------------------------------------------------------
                                 Define
@@ -56,10 +56,6 @@
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
 
 static int hawki_step_basic_calib_create(cpl_plugin *) ;
 static int hawki_step_basic_calib_exec(cpl_plugin *) ;
@@ -92,7 +88,7 @@ static int hawki_step_basic_calib_save
  -----------------------------------------------------------------------------*/
 
 static char hawki_step_basic_calib_description[] =
-"hawki_step_basic_calib -- hawki basic reduction utility (flat, dark).\n"
+"(OBSOLETE) hawki_step_basic_calib -- hawki basic reduction utility (flat, dark).\n"
 "The files listed in the Set Of Frames (sof-file) must be tagged:\n"
 "raw-file.fits "HAWKI_IMG_JITTER_RAW" or\n"
 "raw-file.fits "HAWKI_IMG_JITTER_SKY_RAW" \n"
@@ -123,11 +119,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_step_basic_calib",
-                    "Basic reduction recipe",
+                    "(OBSOLETE) Basic reduction recipe",
                     hawki_step_basic_calib_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     "cgarcia@eso.org",
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_step_basic_calib_create,
                     hawki_step_basic_calib_exec,
                     hawki_step_basic_calib_destroy) ;
@@ -228,7 +224,7 @@ static int hawki_step_basic_calib(
     cpl_frameset     * skyframes ;
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) {
+    if (hawki_dfs_set_groups_legacy(framelist)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -380,7 +376,7 @@ static int hawki_step_basic_calib_applycal_qc_save
             cpl_frameset_delete(calib_frameset);
             return -1 ;
         }
-        science_dit = hawki_pfits_get_dit(plist);
+        science_dit = hawki_pfits_get_dit_legacy(plist);
         cpl_imagelist_multiply_scalar(dark_images, science_dit);
         cpl_propertylist_delete(plist);
     }
@@ -473,7 +469,7 @@ static int hawki_step_basic_calib_applycal_qc_save
     {
         cpl_msg_warning(__func__,"Probably some data could not be saved. "
                                  "Check permisions or disk space");
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return 1;
     }
     return 0;
