@@ -40,25 +40,20 @@
 #include "irplib_utils.h"
 #include "irplib_calib.h"
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_obj_det.h"
 #include "hawki_mask.h"
 #include "hawki_image_stats.h"
 #include "hawki_calib.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_step_detect_obj_create(cpl_plugin *) ;
 static int hawki_step_detect_obj_exec(cpl_plugin *) ;
 static int hawki_step_detect_obj_destroy(cpl_plugin *) ;
@@ -110,7 +105,7 @@ static struct
 } hawki_step_detect_obj_output;
 
 static char hawki_step_detect_obj_description[] =
-"hawki_step_detect_obj -- hawki detect objects recipe.\n"
+"(OBSOLETE) hawki_step_detect_obj -- hawki detect objects recipe.\n"
 "This recipe detects objects from the combined image creating a mask\n"
 "and a list of object properties\n"
 "The input of the recipe files listed in the Set Of Frames (sof-file)\n"
@@ -148,11 +143,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_step_detect_obj",
-                    "Object detection recipe",
+                    "(OBSOLETE) Object detection recipe",
                     hawki_step_detect_obj_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_step_detect_obj_create,
                     hawki_step_detect_obj_exec,
                     hawki_step_detect_obj_destroy) ;
@@ -291,7 +286,7 @@ static int hawki_step_detect_obj(
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) {
+    if (hawki_dfs_set_groups_legacy(framelist)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -960,7 +955,7 @@ static int hawki_step_detect_obj_save
     cpl_free(qclists) ;
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return -1;
     }
     return  0;
@@ -998,7 +993,7 @@ static void hawki_step_detect_obj_get_pscale
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
         cpl_msg_error(__func__, "Missing PIXSCALE keyword in FITS header") ;
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return;
     }
 }
