@@ -29,23 +29,18 @@
 #include <math.h>
 #include <cpl.h>
 
-#include "hawki_dfs.h"
+#include "hawki_dfs_legacy.h"
 #include "hawki_load.h"
 #include "hawki_save.h"
-#include "hawki_pfits.h"
+#include "hawki_pfits_legacy.h"
 #include "hawki_image_stats.h"
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_step_stats_create(cpl_plugin *) ;
 static int hawki_step_stats_exec(cpl_plugin *) ;
 static int hawki_step_stats_destroy(cpl_plugin *) ;
@@ -70,7 +65,7 @@ static int hawki_step_stats_save
  -----------------------------------------------------------------------------*/
 
 static char hawki_step_stats_description[] =
-"hawki_step_stats -- hawki statistics utility (mean, stdev, ...).\n"
+"(OBSOLETE) hawki_step_stats -- hawki statistics utility (mean, stdev, ...).\n"
 "The files listed in the Set Of Frames (sof-file) must be tagged:\n"
 "raw-jitter.fits "HAWKI_IMG_JITTER_RAW" or\n"
 "bkg.fits "HAWKI_CALPRO_BKGIMAGE" or\n"
@@ -111,11 +106,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_step_stats",
-                    "Standard statistics utility",
+                    "(OBSOLETE) Standard statistics utility",
                     hawki_step_stats_description,
-                    "Cesar Enrique Garcia Dabo",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_step_stats_create,
                     hawki_step_stats_exec,
                     hawki_step_stats_destroy) ;
@@ -219,7 +214,7 @@ static int hawki_step_stats(
     char                protype[1024];
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) 
+    if (hawki_dfs_set_groups_legacy(framelist)) 
     {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1;
@@ -422,7 +417,7 @@ static int hawki_step_stats_save
 
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return -1;
     }
     return  0;
