@@ -38,20 +38,15 @@
 
 #include "irplib_utils.h"
 
-#include "hawki_utils.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_utils_legacy.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 #include "hawki_load.h"
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
 
-#ifdef __cplusplus
-extern "C"
-#endif
-int cpl_plugin_get_info(cpl_pluginlist * list);
-
 static int hawki_step_stitch_create(cpl_plugin *) ;
 static int hawki_step_stitch_exec(cpl_plugin *) ;
 static int hawki_step_stitch_destroy(cpl_plugin *) ;
@@ -67,7 +62,7 @@ static int hawki_step_stitch_save
  -----------------------------------------------------------------------------*/
 
 static char hawki_step_stitch_description[] =
-"hawki_step_stitch -- Stitching utility\n"
+"(OBSOLETE) hawki_step_stitch -- Stitching utility\n"
 "This recipe accepts 1 parameter:\n"
 "First parameter:   the HAWKI image to stitch "
 "                   (PRO CATG = "HAWKI_CALPRO_COMBINED")\n"
@@ -100,11 +95,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_step_stitch",
-                    "Stitching utility",
+                    "(OBSOLETE) Stitching utility",
                     hawki_step_stitch_description,
-                    "Cesar Enrique Garcia",
+                    "ESO Pipeline Group",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_step_stitch_create,
                     hawki_step_stitch_exec,
                     hawki_step_stitch_destroy) ;
@@ -210,7 +205,7 @@ static int hawki_step_stitch(
     /* Retrieve input parameters */
  
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(frameset)) {
+    if (hawki_dfs_set_groups_legacy(frameset)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -348,7 +343,7 @@ static int hawki_step_stitch_save
     cpl_msg_indent_less();
     if(!cpl_errorstate_is_equal(error_prevstate))
     {
-        cpl_errorstate_set(CPL_ERROR_NONE);
+        cpl_error_reset();
         return -1;
     }
     return  0;
