@@ -34,15 +34,16 @@
  -----------------------------------------------------------------------------*/
 
 #include <math.h>
+#include <locale.h>
 #include <cpl.h>
 
 #include "irplib_utils.h"
 #include "irplib_stdstar.h"
 
-#include "hawki_utils.h"
+#include "hawki_utils_legacy.h"
 #include "hawki_load.h"
-#include "hawki_pfits.h"
-#include "hawki_dfs.h"
+#include "hawki_pfits_legacy.h"
+#include "hawki_dfs_legacy.h"
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
@@ -59,7 +60,7 @@ static cpl_table * hawki_util_stdstars_convert(const char *) ;
  -----------------------------------------------------------------------------*/
 
 static char hawki_util_stdstars_description[] = 
-"hawki_util_stdstars -- HAWK-I standard stars catalog creation.\n"
+"(OBSOLETE) hawki_util_stdstars -- HAWK-I standard stars catalog creation.\n"
 "The files listed in the Set Of Frames (sof-file) must be tagged:\n"
 "raw-file.txt "HAWKI_UTIL_STDSTARS_RAW"\n" ;
 
@@ -86,11 +87,11 @@ int cpl_plugin_get_info(cpl_pluginlist * list)
                     HAWKI_BINARY_VERSION,
                     CPL_PLUGIN_TYPE_RECIPE,
                     "hawki_util_stdstars",
-                    "Standard stars catalog creation",
+                    "(OBSOLETE) Standard stars catalog creation",
                     hawki_util_stdstars_description,
                     "Cesar Enrique Garcia Dabo",
                     PACKAGE_BUGREPORT,  
-                    hawki_get_license(),
+                    hawki_get_license_legacy(),
                     hawki_util_stdstars_create,
                     hawki_util_stdstars_exec,
                     hawki_util_stdstars_destroy) ;
@@ -183,7 +184,7 @@ static int hawki_util_stdstars(
 
     
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (hawki_dfs_set_groups(framelist)) {
+    if (hawki_dfs_set_groups_legacy(framelist)) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         return -1 ;
     }
@@ -291,6 +292,7 @@ static cpl_table * hawki_util_stdstars_convert(const char * filename)
         return NULL ;
     }
     nbentries = 0 ;
+    setlocale(LC_NUMERIC, "C"); // Behaviour of sscanf depends on the locale
     while (fgets(line, 1024, in) != NULL) {
         if (line[0] != '#') {
             if (sscanf(line, "%510s %lg %lg %510s %lg %lg %lg %lg", 
