@@ -187,6 +187,8 @@ class DataPlotterManager(object):
             self.n_sci_frames = len(self.sci_frames[self.img_cat])
             self.cur_sci_frame = 0
             self.n_extn = len(self.sci_frames[self.img_cat][0].hdulist())-1  # number of extensions, assumed to be same for all fitsFiles
+            if (self.n_extn > 4):
+                self.n_extn = 4 # Adaptiv optic extensions are present in the file
 
             # Don't read the individual calibrated science images in here 
             #   for memory/performance reasons. Read them in below as needed.
