@@ -148,6 +148,8 @@ class DataPlotterManager(object):
             self.n_std_frames = len(self.std_frames[self.img_cat])
             self.cur_std_frame = 0
             self.n_extn = len(self.std_frames[self.img_cat][0].hdulist())-1  # number of extensions, assumed to be same for all fitsFiles
+            if (self.n_extn > 4):
+                self.n_extn = 4 # Adaptiv optic extensions are present in the file
 
             # Don't read the individual calibrated standard images in here 
             #   for memory/performance reasons. Read them in below as needed.
